# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['UnifiedAgentConfigurationArgs', 'UnifiedAgentConfiguration']

@pulumi.input_type
class UnifiedAgentConfigurationArgs:
    def __init__(__self__, *,
                 compartment_id: pulumi.Input[str],
                 is_enabled: pulumi.Input[bool],
                 service_configuration: pulumi.Input['UnifiedAgentConfigurationServiceConfigurationArgs'],
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 group_association: Optional[pulumi.Input['UnifiedAgentConfigurationGroupAssociationArgs']] = None):
        """
        The set of arguments for constructing a UnifiedAgentConfiguration resource.
        :param pulumi.Input[str] compartment_id: (Updatable) The OCID of the compartment that the resource belongs to.
        :param pulumi.Input[bool] is_enabled: (Updatable) Whether or not this resource is currently enabled.
        :param pulumi.Input['UnifiedAgentConfigurationServiceConfigurationArgs'] service_configuration: (Updatable) Top level Unified Agent service configuration object.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] description: (Updatable) Description for this resource.
        :param pulumi.Input[str] display_name: (Updatable) The user-friendly display name. This must be unique within the enclosing resource, and it's changeable. Avoid entering confidential information.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        :param pulumi.Input['UnifiedAgentConfigurationGroupAssociationArgs'] group_association: (Updatable) Groups using the configuration.
        """
        pulumi.set(__self__, "compartment_id", compartment_id)
        pulumi.set(__self__, "is_enabled", is_enabled)
        pulumi.set(__self__, "service_configuration", service_configuration)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if group_association is not None:
            pulumi.set(__self__, "group_association", group_association)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Input[str]:
        """
        (Updatable) The OCID of the compartment that the resource belongs to.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> pulumi.Input[bool]:
        """
        (Updatable) Whether or not this resource is currently enabled.
        """
        return pulumi.get(self, "is_enabled")

    @is_enabled.setter
    def is_enabled(self, value: pulumi.Input[bool]):
        pulumi.set(self, "is_enabled", value)

    @property
    @pulumi.getter(name="serviceConfiguration")
    def service_configuration(self) -> pulumi.Input['UnifiedAgentConfigurationServiceConfigurationArgs']:
        """
        (Updatable) Top level Unified Agent service configuration object.
        """
        return pulumi.get(self, "service_configuration")

    @service_configuration.setter
    def service_configuration(self, value: pulumi.Input['UnifiedAgentConfigurationServiceConfigurationArgs']):
        pulumi.set(self, "service_configuration", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Description for this resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The user-friendly display name. This must be unique within the enclosing resource, and it's changeable. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter(name="groupAssociation")
    def group_association(self) -> Optional[pulumi.Input['UnifiedAgentConfigurationGroupAssociationArgs']]:
        """
        (Updatable) Groups using the configuration.
        """
        return pulumi.get(self, "group_association")

    @group_association.setter
    def group_association(self, value: Optional[pulumi.Input['UnifiedAgentConfigurationGroupAssociationArgs']]):
        pulumi.set(self, "group_association", value)


@pulumi.input_type
class _UnifiedAgentConfigurationState:
    def __init__(__self__, *,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 configuration_state: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 group_association: Optional[pulumi.Input['UnifiedAgentConfigurationGroupAssociationArgs']] = None,
                 is_enabled: Optional[pulumi.Input[bool]] = None,
                 service_configuration: Optional[pulumi.Input['UnifiedAgentConfigurationServiceConfigurationArgs']] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 time_created: Optional[pulumi.Input[str]] = None,
                 time_last_modified: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering UnifiedAgentConfiguration resources.
        :param pulumi.Input[str] compartment_id: (Updatable) The OCID of the compartment that the resource belongs to.
        :param pulumi.Input[str] configuration_state: State of unified agent service configuration.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] description: (Updatable) Description for this resource.
        :param pulumi.Input[str] display_name: (Updatable) The user-friendly display name. This must be unique within the enclosing resource, and it's changeable. Avoid entering confidential information.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        :param pulumi.Input['UnifiedAgentConfigurationGroupAssociationArgs'] group_association: (Updatable) Groups using the configuration.
        :param pulumi.Input[bool] is_enabled: (Updatable) Whether or not this resource is currently enabled.
        :param pulumi.Input['UnifiedAgentConfigurationServiceConfigurationArgs'] service_configuration: (Updatable) Top level Unified Agent service configuration object.
        :param pulumi.Input[str] state: The pipeline state.
        :param pulumi.Input[str] time_created: Time the resource was created.
        :param pulumi.Input[str] time_last_modified: Time the resource was last modified.
        """
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if configuration_state is not None:
            pulumi.set(__self__, "configuration_state", configuration_state)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if group_association is not None:
            pulumi.set(__self__, "group_association", group_association)
        if is_enabled is not None:
            pulumi.set(__self__, "is_enabled", is_enabled)
        if service_configuration is not None:
            pulumi.set(__self__, "service_configuration", service_configuration)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if time_created is not None:
            pulumi.set(__self__, "time_created", time_created)
        if time_last_modified is not None:
            pulumi.set(__self__, "time_last_modified", time_last_modified)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The OCID of the compartment that the resource belongs to.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="configurationState")
    def configuration_state(self) -> Optional[pulumi.Input[str]]:
        """
        State of unified agent service configuration.
        """
        return pulumi.get(self, "configuration_state")

    @configuration_state.setter
    def configuration_state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "configuration_state", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Description for this resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The user-friendly display name. This must be unique within the enclosing resource, and it's changeable. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter(name="groupAssociation")
    def group_association(self) -> Optional[pulumi.Input['UnifiedAgentConfigurationGroupAssociationArgs']]:
        """
        (Updatable) Groups using the configuration.
        """
        return pulumi.get(self, "group_association")

    @group_association.setter
    def group_association(self, value: Optional[pulumi.Input['UnifiedAgentConfigurationGroupAssociationArgs']]):
        pulumi.set(self, "group_association", value)

    @property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        (Updatable) Whether or not this resource is currently enabled.
        """
        return pulumi.get(self, "is_enabled")

    @is_enabled.setter
    def is_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_enabled", value)

    @property
    @pulumi.getter(name="serviceConfiguration")
    def service_configuration(self) -> Optional[pulumi.Input['UnifiedAgentConfigurationServiceConfigurationArgs']]:
        """
        (Updatable) Top level Unified Agent service configuration object.
        """
        return pulumi.get(self, "service_configuration")

    @service_configuration.setter
    def service_configuration(self, value: Optional[pulumi.Input['UnifiedAgentConfigurationServiceConfigurationArgs']]):
        pulumi.set(self, "service_configuration", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        The pipeline state.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> Optional[pulumi.Input[str]]:
        """
        Time the resource was created.
        """
        return pulumi.get(self, "time_created")

    @time_created.setter
    def time_created(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_created", value)

    @property
    @pulumi.getter(name="timeLastModified")
    def time_last_modified(self) -> Optional[pulumi.Input[str]]:
        """
        Time the resource was last modified.
        """
        return pulumi.get(self, "time_last_modified")

    @time_last_modified.setter
    def time_last_modified(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_last_modified", value)


class UnifiedAgentConfiguration(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 group_association: Optional[pulumi.Input[pulumi.InputType['UnifiedAgentConfigurationGroupAssociationArgs']]] = None,
                 is_enabled: Optional[pulumi.Input[bool]] = None,
                 service_configuration: Optional[pulumi.Input[pulumi.InputType['UnifiedAgentConfigurationServiceConfigurationArgs']]] = None,
                 __props__=None):
        """
        This resource provides the Unified Agent Configuration resource in Oracle Cloud Infrastructure Logging service.

        Create unified agent configuration registration.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_unified_agent_configuration = oci.logging.UnifiedAgentConfiguration("testUnifiedAgentConfiguration",
            compartment_id=var["compartment_id"],
            is_enabled=var["unified_agent_configuration_is_enabled"],
            description=var["unified_agent_configuration_description"],
            display_name=var["unified_agent_configuration_display_name"],
            service_configuration=oci.logging.UnifiedAgentConfigurationServiceConfigurationArgs(
                configuration_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                destination=oci.logging.UnifiedAgentConfigurationServiceConfigurationDestinationArgs(
                    log_object_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                ),
                sources=[oci.logging.UnifiedAgentConfigurationServiceConfigurationSourceArgs(
                    source_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    channels=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    parser=oci.logging.UnifiedAgentConfigurationServiceConfigurationSourceParserArgs(
                        parser_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        delimiter=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        expression=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        field_time_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        formats=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        format_firstline=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        grok_failure_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        grok_name_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_estimate_current_event=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_keep_time_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_merge_cri_fields=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_null_empty_string=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_support_colonless_ident=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_with_priority=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        keys=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        message_format=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        message_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        multi_line_start_regexp=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        nested_parser=oci.logging.UnifiedAgentConfigurationServiceConfigurationSourceParserNestedParserArgs(
                            time_format=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            field_time_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            is_keep_time_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                        null_value_pattern=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        patterns=[oci.logging.UnifiedAgentConfigurationServiceConfigurationSourceParserPatternArgs(
                            field_time_format=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            field_time_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            field_time_zone=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            pattern=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        )],
                        rfc5424time_format=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        syslog_parser_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        time_format=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        time_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        timeout_in_milliseconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        types=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    paths=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                )],
            ),
            defined_tags={
                "Operations.CostCenter": "42",
            },
            freeform_tags={
                "Department": "Finance",
            },
            group_association=oci.logging.UnifiedAgentConfigurationGroupAssociationArgs(
                group_lists=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ))
        ```

        ## Import

        UnifiedAgentConfigurations can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Logging/unifiedAgentConfiguration:UnifiedAgentConfiguration test_unified_agent_configuration "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] compartment_id: (Updatable) The OCID of the compartment that the resource belongs to.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] description: (Updatable) Description for this resource.
        :param pulumi.Input[str] display_name: (Updatable) The user-friendly display name. This must be unique within the enclosing resource, and it's changeable. Avoid entering confidential information.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        :param pulumi.Input[pulumi.InputType['UnifiedAgentConfigurationGroupAssociationArgs']] group_association: (Updatable) Groups using the configuration.
        :param pulumi.Input[bool] is_enabled: (Updatable) Whether or not this resource is currently enabled.
        :param pulumi.Input[pulumi.InputType['UnifiedAgentConfigurationServiceConfigurationArgs']] service_configuration: (Updatable) Top level Unified Agent service configuration object.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UnifiedAgentConfigurationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Unified Agent Configuration resource in Oracle Cloud Infrastructure Logging service.

        Create unified agent configuration registration.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_unified_agent_configuration = oci.logging.UnifiedAgentConfiguration("testUnifiedAgentConfiguration",
            compartment_id=var["compartment_id"],
            is_enabled=var["unified_agent_configuration_is_enabled"],
            description=var["unified_agent_configuration_description"],
            display_name=var["unified_agent_configuration_display_name"],
            service_configuration=oci.logging.UnifiedAgentConfigurationServiceConfigurationArgs(
                configuration_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                destination=oci.logging.UnifiedAgentConfigurationServiceConfigurationDestinationArgs(
                    log_object_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                ),
                sources=[oci.logging.UnifiedAgentConfigurationServiceConfigurationSourceArgs(
                    source_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    channels=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    parser=oci.logging.UnifiedAgentConfigurationServiceConfigurationSourceParserArgs(
                        parser_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        delimiter=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        expression=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        field_time_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        formats=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        format_firstline=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        grok_failure_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        grok_name_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_estimate_current_event=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_keep_time_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_merge_cri_fields=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_null_empty_string=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_support_colonless_ident=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        is_with_priority=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        keys=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        message_format=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        message_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        multi_line_start_regexp=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        nested_parser=oci.logging.UnifiedAgentConfigurationServiceConfigurationSourceParserNestedParserArgs(
                            time_format=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            field_time_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            is_keep_time_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        ),
                        null_value_pattern=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        patterns=[oci.logging.UnifiedAgentConfigurationServiceConfigurationSourceParserPatternArgs(
                            field_time_format=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            field_time_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            field_time_zone=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                            pattern=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        )],
                        rfc5424time_format=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        syslog_parser_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        time_format=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        time_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        timeout_in_milliseconds=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                        types=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    ),
                    paths=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                )],
            ),
            defined_tags={
                "Operations.CostCenter": "42",
            },
            freeform_tags={
                "Department": "Finance",
            },
            group_association=oci.logging.UnifiedAgentConfigurationGroupAssociationArgs(
                group_lists=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ))
        ```

        ## Import

        UnifiedAgentConfigurations can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Logging/unifiedAgentConfiguration:UnifiedAgentConfiguration test_unified_agent_configuration "id"
        ```

        :param str resource_name: The name of the resource.
        :param UnifiedAgentConfigurationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UnifiedAgentConfigurationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 group_association: Optional[pulumi.Input[pulumi.InputType['UnifiedAgentConfigurationGroupAssociationArgs']]] = None,
                 is_enabled: Optional[pulumi.Input[bool]] = None,
                 service_configuration: Optional[pulumi.Input[pulumi.InputType['UnifiedAgentConfigurationServiceConfigurationArgs']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UnifiedAgentConfigurationArgs.__new__(UnifiedAgentConfigurationArgs)

            if compartment_id is None and not opts.urn:
                raise TypeError("Missing required property 'compartment_id'")
            __props__.__dict__["compartment_id"] = compartment_id
            __props__.__dict__["defined_tags"] = defined_tags
            __props__.__dict__["description"] = description
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["freeform_tags"] = freeform_tags
            __props__.__dict__["group_association"] = group_association
            if is_enabled is None and not opts.urn:
                raise TypeError("Missing required property 'is_enabled'")
            __props__.__dict__["is_enabled"] = is_enabled
            if service_configuration is None and not opts.urn:
                raise TypeError("Missing required property 'service_configuration'")
            __props__.__dict__["service_configuration"] = service_configuration
            __props__.__dict__["configuration_state"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["time_created"] = None
            __props__.__dict__["time_last_modified"] = None
        super(UnifiedAgentConfiguration, __self__).__init__(
            'oci:Logging/unifiedAgentConfiguration:UnifiedAgentConfiguration',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            compartment_id: Optional[pulumi.Input[str]] = None,
            configuration_state: Optional[pulumi.Input[str]] = None,
            defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            description: Optional[pulumi.Input[str]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            group_association: Optional[pulumi.Input[pulumi.InputType['UnifiedAgentConfigurationGroupAssociationArgs']]] = None,
            is_enabled: Optional[pulumi.Input[bool]] = None,
            service_configuration: Optional[pulumi.Input[pulumi.InputType['UnifiedAgentConfigurationServiceConfigurationArgs']]] = None,
            state: Optional[pulumi.Input[str]] = None,
            time_created: Optional[pulumi.Input[str]] = None,
            time_last_modified: Optional[pulumi.Input[str]] = None) -> 'UnifiedAgentConfiguration':
        """
        Get an existing UnifiedAgentConfiguration resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] compartment_id: (Updatable) The OCID of the compartment that the resource belongs to.
        :param pulumi.Input[str] configuration_state: State of unified agent service configuration.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] description: (Updatable) Description for this resource.
        :param pulumi.Input[str] display_name: (Updatable) The user-friendly display name. This must be unique within the enclosing resource, and it's changeable. Avoid entering confidential information.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        :param pulumi.Input[pulumi.InputType['UnifiedAgentConfigurationGroupAssociationArgs']] group_association: (Updatable) Groups using the configuration.
        :param pulumi.Input[bool] is_enabled: (Updatable) Whether or not this resource is currently enabled.
        :param pulumi.Input[pulumi.InputType['UnifiedAgentConfigurationServiceConfigurationArgs']] service_configuration: (Updatable) Top level Unified Agent service configuration object.
        :param pulumi.Input[str] state: The pipeline state.
        :param pulumi.Input[str] time_created: Time the resource was created.
        :param pulumi.Input[str] time_last_modified: Time the resource was last modified.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UnifiedAgentConfigurationState.__new__(_UnifiedAgentConfigurationState)

        __props__.__dict__["compartment_id"] = compartment_id
        __props__.__dict__["configuration_state"] = configuration_state
        __props__.__dict__["defined_tags"] = defined_tags
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["freeform_tags"] = freeform_tags
        __props__.__dict__["group_association"] = group_association
        __props__.__dict__["is_enabled"] = is_enabled
        __props__.__dict__["service_configuration"] = service_configuration
        __props__.__dict__["state"] = state
        __props__.__dict__["time_created"] = time_created
        __props__.__dict__["time_last_modified"] = time_last_modified
        return UnifiedAgentConfiguration(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Output[str]:
        """
        (Updatable) The OCID of the compartment that the resource belongs to.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="configurationState")
    def configuration_state(self) -> pulumi.Output[str]:
        """
        State of unified agent service configuration.
        """
        return pulumi.get(self, "configuration_state")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        (Updatable) Description for this resource.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        (Updatable) The user-friendly display name. This must be unique within the enclosing resource, and it's changeable. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter(name="groupAssociation")
    def group_association(self) -> pulumi.Output['outputs.UnifiedAgentConfigurationGroupAssociation']:
        """
        (Updatable) Groups using the configuration.
        """
        return pulumi.get(self, "group_association")

    @property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> pulumi.Output[bool]:
        """
        (Updatable) Whether or not this resource is currently enabled.
        """
        return pulumi.get(self, "is_enabled")

    @property
    @pulumi.getter(name="serviceConfiguration")
    def service_configuration(self) -> pulumi.Output['outputs.UnifiedAgentConfigurationServiceConfiguration']:
        """
        (Updatable) Top level Unified Agent service configuration object.
        """
        return pulumi.get(self, "service_configuration")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        The pipeline state.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> pulumi.Output[str]:
        """
        Time the resource was created.
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeLastModified")
    def time_last_modified(self) -> pulumi.Output[str]:
        """
        Time the resource was last modified.
        """
        return pulumi.get(self, "time_last_modified")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetFusionEnvironmentRefreshActivityResult',
    'AwaitableGetFusionEnvironmentRefreshActivityResult',
    'get_fusion_environment_refresh_activity',
    'get_fusion_environment_refresh_activity_output',
]

@pulumi.output_type
class GetFusionEnvironmentRefreshActivityResult:
    """
    A collection of values returned by getFusionEnvironmentRefreshActivity.
    """
    def __init__(__self__, display_name=None, fusion_environment_id=None, id=None, lifecycle_details=None, refresh_activity_id=None, refresh_issue_details_lists=None, service_availability=None, source_fusion_environment_id=None, state=None, time_accepted=None, time_expected_finish=None, time_finished=None, time_of_restoration_point=None, time_updated=None):
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if fusion_environment_id and not isinstance(fusion_environment_id, str):
            raise TypeError("Expected argument 'fusion_environment_id' to be a str")
        pulumi.set(__self__, "fusion_environment_id", fusion_environment_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if lifecycle_details and not isinstance(lifecycle_details, str):
            raise TypeError("Expected argument 'lifecycle_details' to be a str")
        pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if refresh_activity_id and not isinstance(refresh_activity_id, str):
            raise TypeError("Expected argument 'refresh_activity_id' to be a str")
        pulumi.set(__self__, "refresh_activity_id", refresh_activity_id)
        if refresh_issue_details_lists and not isinstance(refresh_issue_details_lists, list):
            raise TypeError("Expected argument 'refresh_issue_details_lists' to be a list")
        pulumi.set(__self__, "refresh_issue_details_lists", refresh_issue_details_lists)
        if service_availability and not isinstance(service_availability, str):
            raise TypeError("Expected argument 'service_availability' to be a str")
        pulumi.set(__self__, "service_availability", service_availability)
        if source_fusion_environment_id and not isinstance(source_fusion_environment_id, str):
            raise TypeError("Expected argument 'source_fusion_environment_id' to be a str")
        pulumi.set(__self__, "source_fusion_environment_id", source_fusion_environment_id)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if time_accepted and not isinstance(time_accepted, str):
            raise TypeError("Expected argument 'time_accepted' to be a str")
        pulumi.set(__self__, "time_accepted", time_accepted)
        if time_expected_finish and not isinstance(time_expected_finish, str):
            raise TypeError("Expected argument 'time_expected_finish' to be a str")
        pulumi.set(__self__, "time_expected_finish", time_expected_finish)
        if time_finished and not isinstance(time_finished, str):
            raise TypeError("Expected argument 'time_finished' to be a str")
        pulumi.set(__self__, "time_finished", time_finished)
        if time_of_restoration_point and not isinstance(time_of_restoration_point, str):
            raise TypeError("Expected argument 'time_of_restoration_point' to be a str")
        pulumi.set(__self__, "time_of_restoration_point", time_of_restoration_point)
        if time_updated and not isinstance(time_updated, str):
            raise TypeError("Expected argument 'time_updated' to be a str")
        pulumi.set(__self__, "time_updated", time_updated)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        A friendly name for the refresh activity. Can be changed later.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="fusionEnvironmentId")
    def fusion_environment_id(self) -> str:
        return pulumi.get(self, "fusion_environment_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The unique identifier (OCID) of the refresh activity. Can't be changed after creation.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> str:
        """
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
        """
        return pulumi.get(self, "lifecycle_details")

    @property
    @pulumi.getter(name="refreshActivityId")
    def refresh_activity_id(self) -> str:
        return pulumi.get(self, "refresh_activity_id")

    @property
    @pulumi.getter(name="refreshIssueDetailsLists")
    def refresh_issue_details_lists(self) -> Sequence['outputs.GetFusionEnvironmentRefreshActivityRefreshIssueDetailsListResult']:
        """
        Details of refresh investigation information, each item represents a different issue.
        """
        return pulumi.get(self, "refresh_issue_details_lists")

    @property
    @pulumi.getter(name="serviceAvailability")
    def service_availability(self) -> str:
        """
        Service availability / impact during refresh activity execution up down
        """
        return pulumi.get(self, "service_availability")

    @property
    @pulumi.getter(name="sourceFusionEnvironmentId")
    def source_fusion_environment_id(self) -> str:
        """
        The OCID of the Fusion environment that is the source environment for the refresh.
        """
        return pulumi.get(self, "source_fusion_environment_id")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The current state of the refreshActivity.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeAccepted")
    def time_accepted(self) -> str:
        """
        The time the refresh activity record was created. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_accepted")

    @property
    @pulumi.getter(name="timeExpectedFinish")
    def time_expected_finish(self) -> str:
        """
        The time the refresh activity is scheduled to end. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_expected_finish")

    @property
    @pulumi.getter(name="timeFinished")
    def time_finished(self) -> str:
        """
        The time the refresh activity actually completed / cancelled / failed. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_finished")

    @property
    @pulumi.getter(name="timeOfRestorationPoint")
    def time_of_restoration_point(self) -> str:
        """
        The date and time of the most recent source environment backup used for the environment refresh.
        """
        return pulumi.get(self, "time_of_restoration_point")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> str:
        """
        The time the refresh activity record was updated. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_updated")


class AwaitableGetFusionEnvironmentRefreshActivityResult(GetFusionEnvironmentRefreshActivityResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFusionEnvironmentRefreshActivityResult(
            display_name=self.display_name,
            fusion_environment_id=self.fusion_environment_id,
            id=self.id,
            lifecycle_details=self.lifecycle_details,
            refresh_activity_id=self.refresh_activity_id,
            refresh_issue_details_lists=self.refresh_issue_details_lists,
            service_availability=self.service_availability,
            source_fusion_environment_id=self.source_fusion_environment_id,
            state=self.state,
            time_accepted=self.time_accepted,
            time_expected_finish=self.time_expected_finish,
            time_finished=self.time_finished,
            time_of_restoration_point=self.time_of_restoration_point,
            time_updated=self.time_updated)


def get_fusion_environment_refresh_activity(fusion_environment_id: Optional[str] = None,
                                            refresh_activity_id: Optional[str] = None,
                                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFusionEnvironmentRefreshActivityResult:
    """
    This data source provides details about a specific Fusion Environment Refresh Activity resource in Oracle Cloud Infrastructure Fusion Apps service.

    Gets a RefreshActivity by identifier

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_fusion_environment_refresh_activity = oci.Functions.get_fusion_environment_refresh_activity(fusion_environment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        refresh_activity_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str fusion_environment_id: unique FusionEnvironment identifier
    :param str refresh_activity_id: The unique identifier (OCID) of the Refresh activity.
    """
    __args__ = dict()
    __args__['fusionEnvironmentId'] = fusion_environment_id
    __args__['refreshActivityId'] = refresh_activity_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Functions/getFusionEnvironmentRefreshActivity:getFusionEnvironmentRefreshActivity', __args__, opts=opts, typ=GetFusionEnvironmentRefreshActivityResult).value

    return AwaitableGetFusionEnvironmentRefreshActivityResult(
        display_name=__ret__.display_name,
        fusion_environment_id=__ret__.fusion_environment_id,
        id=__ret__.id,
        lifecycle_details=__ret__.lifecycle_details,
        refresh_activity_id=__ret__.refresh_activity_id,
        refresh_issue_details_lists=__ret__.refresh_issue_details_lists,
        service_availability=__ret__.service_availability,
        source_fusion_environment_id=__ret__.source_fusion_environment_id,
        state=__ret__.state,
        time_accepted=__ret__.time_accepted,
        time_expected_finish=__ret__.time_expected_finish,
        time_finished=__ret__.time_finished,
        time_of_restoration_point=__ret__.time_of_restoration_point,
        time_updated=__ret__.time_updated)


@_utilities.lift_output_func(get_fusion_environment_refresh_activity)
def get_fusion_environment_refresh_activity_output(fusion_environment_id: Optional[pulumi.Input[str]] = None,
                                                   refresh_activity_id: Optional[pulumi.Input[str]] = None,
                                                   opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetFusionEnvironmentRefreshActivityResult]:
    """
    This data source provides details about a specific Fusion Environment Refresh Activity resource in Oracle Cloud Infrastructure Fusion Apps service.

    Gets a RefreshActivity by identifier

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_fusion_environment_refresh_activity = oci.Functions.get_fusion_environment_refresh_activity(fusion_environment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        refresh_activity_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str fusion_environment_id: unique FusionEnvironment identifier
    :param str refresh_activity_id: The unique identifier (OCID) of the Refresh activity.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetDeploymentBackupsResult',
    'AwaitableGetDeploymentBackupsResult',
    'get_deployment_backups',
    'get_deployment_backups_output',
]

@pulumi.output_type
class GetDeploymentBackupsResult:
    """
    A collection of values returned by getDeploymentBackups.
    """
    def __init__(__self__, compartment_id=None, deployment_backup_collections=None, deployment_id=None, display_name=None, filters=None, id=None, state=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if deployment_backup_collections and not isinstance(deployment_backup_collections, list):
            raise TypeError("Expected argument 'deployment_backup_collections' to be a list")
        pulumi.set(__self__, "deployment_backup_collections", deployment_backup_collections)
        if deployment_id and not isinstance(deployment_id, str):
            raise TypeError("Expected argument 'deployment_id' to be a str")
        pulumi.set(__self__, "deployment_id", deployment_id)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment being referenced.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="deploymentBackupCollections")
    def deployment_backup_collections(self) -> Sequence['outputs.GetDeploymentBackupsDeploymentBackupCollectionResult']:
        """
        The list of deployment_backup_collection.
        """
        return pulumi.get(self, "deployment_backup_collections")

    @property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> Optional[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the deployment being referenced.
        """
        return pulumi.get(self, "deployment_id")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        An object's Display Name.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetDeploymentBackupsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        Possible lifecycle states.
        """
        return pulumi.get(self, "state")


class AwaitableGetDeploymentBackupsResult(GetDeploymentBackupsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDeploymentBackupsResult(
            compartment_id=self.compartment_id,
            deployment_backup_collections=self.deployment_backup_collections,
            deployment_id=self.deployment_id,
            display_name=self.display_name,
            filters=self.filters,
            id=self.id,
            state=self.state)


def get_deployment_backups(compartment_id: Optional[str] = None,
                           deployment_id: Optional[str] = None,
                           display_name: Optional[str] = None,
                           filters: Optional[Sequence[pulumi.InputType['GetDeploymentBackupsFilterArgs']]] = None,
                           state: Optional[str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDeploymentBackupsResult:
    """
    This data source provides the list of Deployment Backups in Oracle Cloud Infrastructure Golden Gate service.

    Lists the Backups in a compartment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_deployment_backups = oci.GoldenGate.get_deployment_backups(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        deployment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID of the compartment that contains the work request. Work requests should be scoped  to the same compartment as the resource the work request affects. If the work request concerns  multiple resources, and those resources are not in the same compartment, it is up to the service team  to pick the primary resource whose compartment should be used.
    :param str deployment_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the deployment in which to list resources.
    :param str display_name: A filter to return only the resources that match the entire 'displayName' given.
    :param str state: A filter to return only the resources that match the 'lifecycleState' given.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['deploymentId'] = deployment_id
    __args__['displayName'] = display_name
    __args__['filters'] = filters
    __args__['state'] = state
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:GoldenGate/getDeploymentBackups:getDeploymentBackups', __args__, opts=opts, typ=GetDeploymentBackupsResult).value

    return AwaitableGetDeploymentBackupsResult(
        compartment_id=__ret__.compartment_id,
        deployment_backup_collections=__ret__.deployment_backup_collections,
        deployment_id=__ret__.deployment_id,
        display_name=__ret__.display_name,
        filters=__ret__.filters,
        id=__ret__.id,
        state=__ret__.state)


@_utilities.lift_output_func(get_deployment_backups)
def get_deployment_backups_output(compartment_id: Optional[pulumi.Input[str]] = None,
                                  deployment_id: Optional[pulumi.Input[Optional[str]]] = None,
                                  display_name: Optional[pulumi.Input[Optional[str]]] = None,
                                  filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetDeploymentBackupsFilterArgs']]]]] = None,
                                  state: Optional[pulumi.Input[Optional[str]]] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDeploymentBackupsResult]:
    """
    This data source provides the list of Deployment Backups in Oracle Cloud Infrastructure Golden Gate service.

    Lists the Backups in a compartment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_deployment_backups = oci.GoldenGate.get_deployment_backups(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        deployment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The OCID of the compartment that contains the work request. Work requests should be scoped  to the same compartment as the resource the work request affects. If the work request concerns  multiple resources, and those resources are not in the same compartment, it is up to the service team  to pick the primary resource whose compartment should be used.
    :param str deployment_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the deployment in which to list resources.
    :param str display_name: A filter to return only the resources that match the entire 'displayName' given.
    :param str state: A filter to return only the resources that match the 'lifecycleState' given.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .db_management_private_endpoint import *
from .external_asm import *
from .external_cluster import *
from .external_cluster_instance import *
from .external_db_node import *
from .external_db_system import *
from .external_db_system_connector import *
from .external_db_system_database_managements_management import *
from .external_db_system_discovery import *
from .external_listener import *
from .get_db_management_private_endpoint import *
from .get_db_management_private_endpoint_associated_database import *
from .get_db_management_private_endpoint_associated_databases import *
from .get_db_management_private_endpoints import *
from .get_external_asm import *
from .get_external_asm_configuration import *
from .get_external_asm_disk_groups import *
from .get_external_asm_instance import *
from .get_external_asm_instances import *
from .get_external_asm_users import *
from .get_external_asms import *
from .get_external_cluster import *
from .get_external_cluster_instance import *
from .get_external_cluster_instances import *
from .get_external_clusters import *
from .get_external_databases import *
from .get_external_db_home import *
from .get_external_db_homes import *
from .get_external_db_node import *
from .get_external_db_nodes import *
from .get_external_db_system import *
from .get_external_db_system_connector import *
from .get_external_db_system_connectors import *
from .get_external_db_system_discoveries import *
from .get_external_db_system_discovery import *
from .get_external_db_systems import *
from .get_external_listener import *
from .get_external_listener_services import *
from .get_external_listeners import *
from .get_job_executions_status import *
from .get_job_executions_statuses import *
from .get_managed_database import *
from .get_managed_database_addm_task import *
from .get_managed_database_addm_tasks import *
from .get_managed_database_alert_log_count import *
from .get_managed_database_alert_log_counts import *
from .get_managed_database_attention_log_count import *
from .get_managed_database_attention_log_counts import *
from .get_managed_database_group import *
from .get_managed_database_groups import *
from .get_managed_database_optimizer_statistics_advisor_execution import *
from .get_managed_database_optimizer_statistics_advisor_execution_script import *
from .get_managed_database_optimizer_statistics_advisor_executions import *
from .get_managed_database_optimizer_statistics_collection_aggregations import *
from .get_managed_database_optimizer_statistics_collection_operation import *
from .get_managed_database_optimizer_statistics_collection_operations import *
from .get_managed_database_sql_tuning_advisor_task import *
from .get_managed_database_sql_tuning_advisor_tasks import *
from .get_managed_database_sql_tuning_advisor_tasks_execution_plan_stats_comparison import *
from .get_managed_database_sql_tuning_advisor_tasks_finding import *
from .get_managed_database_sql_tuning_advisor_tasks_findings import *
from .get_managed_database_sql_tuning_advisor_tasks_recommendation import *
from .get_managed_database_sql_tuning_advisor_tasks_recommendations import *
from .get_managed_database_sql_tuning_advisor_tasks_sql_execution_plan import *
from .get_managed_database_sql_tuning_advisor_tasks_summary_report import *
from .get_managed_database_sql_tuning_set import *
from .get_managed_database_sql_tuning_sets import *
from .get_managed_database_table_statistics import *
from .get_managed_database_user import *
from .get_managed_database_user_consumer_group_privilege import *
from .get_managed_database_user_consumer_group_privileges import *
from .get_managed_database_user_data_access_container import *
from .get_managed_database_user_data_access_containers import *
from .get_managed_database_user_object_privilege import *
from .get_managed_database_user_object_privileges import *
from .get_managed_database_user_proxied_for_user import *
from .get_managed_database_user_proxied_for_users import *
from .get_managed_database_user_role import *
from .get_managed_database_user_roles import *
from .get_managed_database_users import *
from .get_managed_databases import *
from .get_managed_databases_asm_properties import *
from .get_managed_databases_asm_property import *
from .get_managed_databases_database_parameter import *
from .get_managed_databases_database_parameters import *
from .get_managed_databases_user_proxy_user import *
from .get_managed_databases_user_proxy_users import *
from .get_managed_databases_user_system_privilege import *
from .get_managed_databases_user_system_privileges import *
from .managed_database_group import *
from .managed_databases_change_database_parameter import *
from .managed_databases_reset_database_parameter import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['MonitoredResourcesSearchAssociationArgs', 'MonitoredResourcesSearchAssociation']

@pulumi.input_type
class MonitoredResourcesSearchAssociationArgs:
    def __init__(__self__, *,
                 compartment_id: pulumi.Input[str],
                 association_type: Optional[pulumi.Input[str]] = None,
                 destination_resource_id: Optional[pulumi.Input[str]] = None,
                 destination_resource_name: Optional[pulumi.Input[str]] = None,
                 destination_resource_type: Optional[pulumi.Input[str]] = None,
                 source_resource_id: Optional[pulumi.Input[str]] = None,
                 source_resource_name: Optional[pulumi.Input[str]] = None,
                 source_resource_type: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a MonitoredResourcesSearchAssociation resource.
        :param pulumi.Input[str] compartment_id: Compartment Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        :param pulumi.Input[str] association_type: Association type filter to search associated resources.
        :param pulumi.Input[str] destination_resource_id: Destination Monitored Resource Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        :param pulumi.Input[str] destination_resource_name: Source Monitored Resource Name.
        :param pulumi.Input[str] destination_resource_type: Source Monitored Resource Type.
        :param pulumi.Input[str] source_resource_id: Source Monitored Resource Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        :param pulumi.Input[str] source_resource_name: Source Monitored Resource Name.
        :param pulumi.Input[str] source_resource_type: Source Monitored Resource Type. 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        pulumi.set(__self__, "compartment_id", compartment_id)
        if association_type is not None:
            pulumi.set(__self__, "association_type", association_type)
        if destination_resource_id is not None:
            pulumi.set(__self__, "destination_resource_id", destination_resource_id)
        if destination_resource_name is not None:
            pulumi.set(__self__, "destination_resource_name", destination_resource_name)
        if destination_resource_type is not None:
            pulumi.set(__self__, "destination_resource_type", destination_resource_type)
        if source_resource_id is not None:
            pulumi.set(__self__, "source_resource_id", source_resource_id)
        if source_resource_name is not None:
            pulumi.set(__self__, "source_resource_name", source_resource_name)
        if source_resource_type is not None:
            pulumi.set(__self__, "source_resource_type", source_resource_type)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Input[str]:
        """
        Compartment Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="associationType")
    def association_type(self) -> Optional[pulumi.Input[str]]:
        """
        Association type filter to search associated resources.
        """
        return pulumi.get(self, "association_type")

    @association_type.setter
    def association_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "association_type", value)

    @property
    @pulumi.getter(name="destinationResourceId")
    def destination_resource_id(self) -> Optional[pulumi.Input[str]]:
        """
        Destination Monitored Resource Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "destination_resource_id")

    @destination_resource_id.setter
    def destination_resource_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "destination_resource_id", value)

    @property
    @pulumi.getter(name="destinationResourceName")
    def destination_resource_name(self) -> Optional[pulumi.Input[str]]:
        """
        Source Monitored Resource Name.
        """
        return pulumi.get(self, "destination_resource_name")

    @destination_resource_name.setter
    def destination_resource_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "destination_resource_name", value)

    @property
    @pulumi.getter(name="destinationResourceType")
    def destination_resource_type(self) -> Optional[pulumi.Input[str]]:
        """
        Source Monitored Resource Type.
        """
        return pulumi.get(self, "destination_resource_type")

    @destination_resource_type.setter
    def destination_resource_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "destination_resource_type", value)

    @property
    @pulumi.getter(name="sourceResourceId")
    def source_resource_id(self) -> Optional[pulumi.Input[str]]:
        """
        Source Monitored Resource Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "source_resource_id")

    @source_resource_id.setter
    def source_resource_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_resource_id", value)

    @property
    @pulumi.getter(name="sourceResourceName")
    def source_resource_name(self) -> Optional[pulumi.Input[str]]:
        """
        Source Monitored Resource Name.
        """
        return pulumi.get(self, "source_resource_name")

    @source_resource_name.setter
    def source_resource_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_resource_name", value)

    @property
    @pulumi.getter(name="sourceResourceType")
    def source_resource_type(self) -> Optional[pulumi.Input[str]]:
        """
        Source Monitored Resource Type. 


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "source_resource_type")

    @source_resource_type.setter
    def source_resource_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_resource_type", value)


@pulumi.input_type
class _MonitoredResourcesSearchAssociationState:
    def __init__(__self__, *,
                 association_type: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 destination_resource_id: Optional[pulumi.Input[str]] = None,
                 destination_resource_name: Optional[pulumi.Input[str]] = None,
                 destination_resource_type: Optional[pulumi.Input[str]] = None,
                 items: Optional[pulumi.Input[Sequence[pulumi.Input['MonitoredResourcesSearchAssociationItemArgs']]]] = None,
                 source_resource_id: Optional[pulumi.Input[str]] = None,
                 source_resource_name: Optional[pulumi.Input[str]] = None,
                 source_resource_type: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering MonitoredResourcesSearchAssociation resources.
        :param pulumi.Input[str] association_type: Association type filter to search associated resources.
        :param pulumi.Input[str] compartment_id: Compartment Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        :param pulumi.Input[str] destination_resource_id: Destination Monitored Resource Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        :param pulumi.Input[str] destination_resource_name: Source Monitored Resource Name.
        :param pulumi.Input[str] destination_resource_type: Source Monitored Resource Type.
        :param pulumi.Input[Sequence[pulumi.Input['MonitoredResourcesSearchAssociationItemArgs']]] items: List of Monitored Resource Associations.
        :param pulumi.Input[str] source_resource_id: Source Monitored Resource Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        :param pulumi.Input[str] source_resource_name: Source Monitored Resource Name.
        :param pulumi.Input[str] source_resource_type: Source Monitored Resource Type. 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        if association_type is not None:
            pulumi.set(__self__, "association_type", association_type)
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if destination_resource_id is not None:
            pulumi.set(__self__, "destination_resource_id", destination_resource_id)
        if destination_resource_name is not None:
            pulumi.set(__self__, "destination_resource_name", destination_resource_name)
        if destination_resource_type is not None:
            pulumi.set(__self__, "destination_resource_type", destination_resource_type)
        if items is not None:
            pulumi.set(__self__, "items", items)
        if source_resource_id is not None:
            pulumi.set(__self__, "source_resource_id", source_resource_id)
        if source_resource_name is not None:
            pulumi.set(__self__, "source_resource_name", source_resource_name)
        if source_resource_type is not None:
            pulumi.set(__self__, "source_resource_type", source_resource_type)

    @property
    @pulumi.getter(name="associationType")
    def association_type(self) -> Optional[pulumi.Input[str]]:
        """
        Association type filter to search associated resources.
        """
        return pulumi.get(self, "association_type")

    @association_type.setter
    def association_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "association_type", value)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        """
        Compartment Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="destinationResourceId")
    def destination_resource_id(self) -> Optional[pulumi.Input[str]]:
        """
        Destination Monitored Resource Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "destination_resource_id")

    @destination_resource_id.setter
    def destination_resource_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "destination_resource_id", value)

    @property
    @pulumi.getter(name="destinationResourceName")
    def destination_resource_name(self) -> Optional[pulumi.Input[str]]:
        """
        Source Monitored Resource Name.
        """
        return pulumi.get(self, "destination_resource_name")

    @destination_resource_name.setter
    def destination_resource_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "destination_resource_name", value)

    @property
    @pulumi.getter(name="destinationResourceType")
    def destination_resource_type(self) -> Optional[pulumi.Input[str]]:
        """
        Source Monitored Resource Type.
        """
        return pulumi.get(self, "destination_resource_type")

    @destination_resource_type.setter
    def destination_resource_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "destination_resource_type", value)

    @property
    @pulumi.getter
    def items(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MonitoredResourcesSearchAssociationItemArgs']]]]:
        """
        List of Monitored Resource Associations.
        """
        return pulumi.get(self, "items")

    @items.setter
    def items(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MonitoredResourcesSearchAssociationItemArgs']]]]):
        pulumi.set(self, "items", value)

    @property
    @pulumi.getter(name="sourceResourceId")
    def source_resource_id(self) -> Optional[pulumi.Input[str]]:
        """
        Source Monitored Resource Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "source_resource_id")

    @source_resource_id.setter
    def source_resource_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_resource_id", value)

    @property
    @pulumi.getter(name="sourceResourceName")
    def source_resource_name(self) -> Optional[pulumi.Input[str]]:
        """
        Source Monitored Resource Name.
        """
        return pulumi.get(self, "source_resource_name")

    @source_resource_name.setter
    def source_resource_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_resource_name", value)

    @property
    @pulumi.getter(name="sourceResourceType")
    def source_resource_type(self) -> Optional[pulumi.Input[str]]:
        """
        Source Monitored Resource Type. 


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "source_resource_type")

    @source_resource_type.setter
    def source_resource_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_resource_type", value)


class MonitoredResourcesSearchAssociation(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 association_type: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 destination_resource_id: Optional[pulumi.Input[str]] = None,
                 destination_resource_name: Optional[pulumi.Input[str]] = None,
                 destination_resource_type: Optional[pulumi.Input[str]] = None,
                 source_resource_id: Optional[pulumi.Input[str]] = None,
                 source_resource_name: Optional[pulumi.Input[str]] = None,
                 source_resource_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource provides the Monitored Resources Search Association resource in Oracle Cloud Infrastructure Stack Monitoring service.

        Search associations in the given compartment based on the search criteria.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_monitored_resources_search_association = oci.stack_monitoring.MonitoredResourcesSearchAssociation("testMonitoredResourcesSearchAssociation",
            compartment_id=var["compartment_id"],
            association_type=var["monitored_resources_search_association_association_type"],
            destination_resource_id=oci_stack_monitoring_destination_resource["test_destination_resource"]["id"],
            destination_resource_name=var["monitored_resources_search_association_destination_resource_name"],
            destination_resource_type=var["monitored_resources_search_association_destination_resource_type"],
            source_resource_id=oci_stack_monitoring_source_resource["test_source_resource"]["id"],
            source_resource_name=var["monitored_resources_search_association_source_resource_name"],
            source_resource_type=var["monitored_resources_search_association_source_resource_type"])
        ```

        ## Import

        MonitoredResourcesSearchAssociations can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:StackMonitoring/monitoredResourcesSearchAssociation:MonitoredResourcesSearchAssociation test_monitored_resources_search_association "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] association_type: Association type filter to search associated resources.
        :param pulumi.Input[str] compartment_id: Compartment Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        :param pulumi.Input[str] destination_resource_id: Destination Monitored Resource Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        :param pulumi.Input[str] destination_resource_name: Source Monitored Resource Name.
        :param pulumi.Input[str] destination_resource_type: Source Monitored Resource Type.
        :param pulumi.Input[str] source_resource_id: Source Monitored Resource Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        :param pulumi.Input[str] source_resource_name: Source Monitored Resource Name.
        :param pulumi.Input[str] source_resource_type: Source Monitored Resource Type. 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MonitoredResourcesSearchAssociationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Monitored Resources Search Association resource in Oracle Cloud Infrastructure Stack Monitoring service.

        Search associations in the given compartment based on the search criteria.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_monitored_resources_search_association = oci.stack_monitoring.MonitoredResourcesSearchAssociation("testMonitoredResourcesSearchAssociation",
            compartment_id=var["compartment_id"],
            association_type=var["monitored_resources_search_association_association_type"],
            destination_resource_id=oci_stack_monitoring_destination_resource["test_destination_resource"]["id"],
            destination_resource_name=var["monitored_resources_search_association_destination_resource_name"],
            destination_resource_type=var["monitored_resources_search_association_destination_resource_type"],
            source_resource_id=oci_stack_monitoring_source_resource["test_source_resource"]["id"],
            source_resource_name=var["monitored_resources_search_association_source_resource_name"],
            source_resource_type=var["monitored_resources_search_association_source_resource_type"])
        ```

        ## Import

        MonitoredResourcesSearchAssociations can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:StackMonitoring/monitoredResourcesSearchAssociation:MonitoredResourcesSearchAssociation test_monitored_resources_search_association "id"
        ```

        :param str resource_name: The name of the resource.
        :param MonitoredResourcesSearchAssociationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MonitoredResourcesSearchAssociationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 association_type: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 destination_resource_id: Optional[pulumi.Input[str]] = None,
                 destination_resource_name: Optional[pulumi.Input[str]] = None,
                 destination_resource_type: Optional[pulumi.Input[str]] = None,
                 source_resource_id: Optional[pulumi.Input[str]] = None,
                 source_resource_name: Optional[pulumi.Input[str]] = None,
                 source_resource_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MonitoredResourcesSearchAssociationArgs.__new__(MonitoredResourcesSearchAssociationArgs)

            __props__.__dict__["association_type"] = association_type
            if compartment_id is None and not opts.urn:
                raise TypeError("Missing required property 'compartment_id'")
            __props__.__dict__["compartment_id"] = compartment_id
            __props__.__dict__["destination_resource_id"] = destination_resource_id
            __props__.__dict__["destination_resource_name"] = destination_resource_name
            __props__.__dict__["destination_resource_type"] = destination_resource_type
            __props__.__dict__["source_resource_id"] = source_resource_id
            __props__.__dict__["source_resource_name"] = source_resource_name
            __props__.__dict__["source_resource_type"] = source_resource_type
            __props__.__dict__["items"] = None
        super(MonitoredResourcesSearchAssociation, __self__).__init__(
            'oci:StackMonitoring/monitoredResourcesSearchAssociation:MonitoredResourcesSearchAssociation',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            association_type: Optional[pulumi.Input[str]] = None,
            compartment_id: Optional[pulumi.Input[str]] = None,
            destination_resource_id: Optional[pulumi.Input[str]] = None,
            destination_resource_name: Optional[pulumi.Input[str]] = None,
            destination_resource_type: Optional[pulumi.Input[str]] = None,
            items: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MonitoredResourcesSearchAssociationItemArgs']]]]] = None,
            source_resource_id: Optional[pulumi.Input[str]] = None,
            source_resource_name: Optional[pulumi.Input[str]] = None,
            source_resource_type: Optional[pulumi.Input[str]] = None) -> 'MonitoredResourcesSearchAssociation':
        """
        Get an existing MonitoredResourcesSearchAssociation resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] association_type: Association type filter to search associated resources.
        :param pulumi.Input[str] compartment_id: Compartment Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        :param pulumi.Input[str] destination_resource_id: Destination Monitored Resource Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        :param pulumi.Input[str] destination_resource_name: Source Monitored Resource Name.
        :param pulumi.Input[str] destination_resource_type: Source Monitored Resource Type.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['MonitoredResourcesSearchAssociationItemArgs']]]] items: List of Monitored Resource Associations.
        :param pulumi.Input[str] source_resource_id: Source Monitored Resource Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        :param pulumi.Input[str] source_resource_name: Source Monitored Resource Name.
        :param pulumi.Input[str] source_resource_type: Source Monitored Resource Type. 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MonitoredResourcesSearchAssociationState.__new__(_MonitoredResourcesSearchAssociationState)

        __props__.__dict__["association_type"] = association_type
        __props__.__dict__["compartment_id"] = compartment_id
        __props__.__dict__["destination_resource_id"] = destination_resource_id
        __props__.__dict__["destination_resource_name"] = destination_resource_name
        __props__.__dict__["destination_resource_type"] = destination_resource_type
        __props__.__dict__["items"] = items
        __props__.__dict__["source_resource_id"] = source_resource_id
        __props__.__dict__["source_resource_name"] = source_resource_name
        __props__.__dict__["source_resource_type"] = source_resource_type
        return MonitoredResourcesSearchAssociation(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="associationType")
    def association_type(self) -> pulumi.Output[Optional[str]]:
        """
        Association type filter to search associated resources.
        """
        return pulumi.get(self, "association_type")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Output[str]:
        """
        Compartment Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="destinationResourceId")
    def destination_resource_id(self) -> pulumi.Output[Optional[str]]:
        """
        Destination Monitored Resource Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "destination_resource_id")

    @property
    @pulumi.getter(name="destinationResourceName")
    def destination_resource_name(self) -> pulumi.Output[Optional[str]]:
        """
        Source Monitored Resource Name.
        """
        return pulumi.get(self, "destination_resource_name")

    @property
    @pulumi.getter(name="destinationResourceType")
    def destination_resource_type(self) -> pulumi.Output[Optional[str]]:
        """
        Source Monitored Resource Type.
        """
        return pulumi.get(self, "destination_resource_type")

    @property
    @pulumi.getter
    def items(self) -> pulumi.Output[Sequence['outputs.MonitoredResourcesSearchAssociationItem']]:
        """
        List of Monitored Resource Associations.
        """
        return pulumi.get(self, "items")

    @property
    @pulumi.getter(name="sourceResourceId")
    def source_resource_id(self) -> pulumi.Output[Optional[str]]:
        """
        Source Monitored Resource Identifier [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
        """
        return pulumi.get(self, "source_resource_id")

    @property
    @pulumi.getter(name="sourceResourceName")
    def source_resource_name(self) -> pulumi.Output[Optional[str]]:
        """
        Source Monitored Resource Name.
        """
        return pulumi.get(self, "source_resource_name")

    @property
    @pulumi.getter(name="sourceResourceType")
    def source_resource_type(self) -> pulumi.Output[Optional[str]]:
        """
        Source Monitored Resource Type. 


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "source_resource_type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetDataSafePrivateEndpointResult',
    'AwaitableGetDataSafePrivateEndpointResult',
    'get_data_safe_private_endpoint',
    'get_data_safe_private_endpoint_output',
]

@pulumi.output_type
class GetDataSafePrivateEndpointResult:
    """
    A collection of values returned by getDataSafePrivateEndpoint.
    """
    def __init__(__self__, compartment_id=None, data_safe_private_endpoint_id=None, defined_tags=None, description=None, display_name=None, endpoint_fqdn=None, freeform_tags=None, id=None, nsg_ids=None, private_endpoint_id=None, private_endpoint_ip=None, state=None, subnet_id=None, system_tags=None, time_created=None, vcn_id=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if data_safe_private_endpoint_id and not isinstance(data_safe_private_endpoint_id, str):
            raise TypeError("Expected argument 'data_safe_private_endpoint_id' to be a str")
        pulumi.set(__self__, "data_safe_private_endpoint_id", data_safe_private_endpoint_id)
        if defined_tags and not isinstance(defined_tags, dict):
            raise TypeError("Expected argument 'defined_tags' to be a dict")
        pulumi.set(__self__, "defined_tags", defined_tags)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if endpoint_fqdn and not isinstance(endpoint_fqdn, str):
            raise TypeError("Expected argument 'endpoint_fqdn' to be a str")
        pulumi.set(__self__, "endpoint_fqdn", endpoint_fqdn)
        if freeform_tags and not isinstance(freeform_tags, dict):
            raise TypeError("Expected argument 'freeform_tags' to be a dict")
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if nsg_ids and not isinstance(nsg_ids, list):
            raise TypeError("Expected argument 'nsg_ids' to be a list")
        pulumi.set(__self__, "nsg_ids", nsg_ids)
        if private_endpoint_id and not isinstance(private_endpoint_id, str):
            raise TypeError("Expected argument 'private_endpoint_id' to be a str")
        pulumi.set(__self__, "private_endpoint_id", private_endpoint_id)
        if private_endpoint_ip and not isinstance(private_endpoint_ip, str):
            raise TypeError("Expected argument 'private_endpoint_ip' to be a str")
        pulumi.set(__self__, "private_endpoint_ip", private_endpoint_ip)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if subnet_id and not isinstance(subnet_id, str):
            raise TypeError("Expected argument 'subnet_id' to be a str")
        pulumi.set(__self__, "subnet_id", subnet_id)
        if system_tags and not isinstance(system_tags, dict):
            raise TypeError("Expected argument 'system_tags' to be a dict")
        pulumi.set(__self__, "system_tags", system_tags)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)
        if vcn_id and not isinstance(vcn_id, str):
            raise TypeError("Expected argument 'vcn_id' to be a str")
        pulumi.set(__self__, "vcn_id", vcn_id)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the compartment.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="dataSafePrivateEndpointId")
    def data_safe_private_endpoint_id(self) -> str:
        return pulumi.get(self, "data_safe_private_endpoint_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)  Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the private endpoint.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        The display name of the private endpoint.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="endpointFqdn")
    def endpoint_fqdn(self) -> str:
        """
        The three-label fully qualified domain name (FQDN) of the private endpoint. The customer VCN's DNS records are updated with this FQDN.
        """
        return pulumi.get(self, "endpoint_fqdn")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm)  Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The OCID of the Data Safe private endpoint.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="nsgIds")
    def nsg_ids(self) -> Sequence[str]:
        """
        The OCIDs of the network security groups that the private endpoint belongs to.
        """
        return pulumi.get(self, "nsg_ids")

    @property
    @pulumi.getter(name="privateEndpointId")
    def private_endpoint_id(self) -> str:
        """
        The OCID of the underlying private endpoint.
        """
        return pulumi.get(self, "private_endpoint_id")

    @property
    @pulumi.getter(name="privateEndpointIp")
    def private_endpoint_ip(self) -> str:
        """
        The private IP address of the private endpoint.
        """
        return pulumi.get(self, "private_endpoint_ip")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The current state of the private endpoint.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> str:
        """
        The OCID of the subnet.
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> Mapping[str, Any]:
        """
        System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags. Example: `{"orcl-cloud.free-tier-retained": "true"}`
        """
        return pulumi.get(self, "system_tags")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The date and time the private endpoint was created, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="vcnId")
    def vcn_id(self) -> str:
        """
        The OCID of the VCN.
        """
        return pulumi.get(self, "vcn_id")


class AwaitableGetDataSafePrivateEndpointResult(GetDataSafePrivateEndpointResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDataSafePrivateEndpointResult(
            compartment_id=self.compartment_id,
            data_safe_private_endpoint_id=self.data_safe_private_endpoint_id,
            defined_tags=self.defined_tags,
            description=self.description,
            display_name=self.display_name,
            endpoint_fqdn=self.endpoint_fqdn,
            freeform_tags=self.freeform_tags,
            id=self.id,
            nsg_ids=self.nsg_ids,
            private_endpoint_id=self.private_endpoint_id,
            private_endpoint_ip=self.private_endpoint_ip,
            state=self.state,
            subnet_id=self.subnet_id,
            system_tags=self.system_tags,
            time_created=self.time_created,
            vcn_id=self.vcn_id)


def get_data_safe_private_endpoint(data_safe_private_endpoint_id: Optional[str] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDataSafePrivateEndpointResult:
    """
    This data source provides details about a specific Data Safe Private Endpoint resource in Oracle Cloud Infrastructure Data Safe service.

    Gets the details of the specified Data Safe private endpoint.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_data_safe_private_endpoint = oci.DataSafe.get_data_safe_private_endpoint(data_safe_private_endpoint_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str data_safe_private_endpoint_id: The OCID of the private endpoint.
    """
    __args__ = dict()
    __args__['dataSafePrivateEndpointId'] = data_safe_private_endpoint_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:DataSafe/getDataSafePrivateEndpoint:getDataSafePrivateEndpoint', __args__, opts=opts, typ=GetDataSafePrivateEndpointResult).value

    return AwaitableGetDataSafePrivateEndpointResult(
        compartment_id=__ret__.compartment_id,
        data_safe_private_endpoint_id=__ret__.data_safe_private_endpoint_id,
        defined_tags=__ret__.defined_tags,
        description=__ret__.description,
        display_name=__ret__.display_name,
        endpoint_fqdn=__ret__.endpoint_fqdn,
        freeform_tags=__ret__.freeform_tags,
        id=__ret__.id,
        nsg_ids=__ret__.nsg_ids,
        private_endpoint_id=__ret__.private_endpoint_id,
        private_endpoint_ip=__ret__.private_endpoint_ip,
        state=__ret__.state,
        subnet_id=__ret__.subnet_id,
        system_tags=__ret__.system_tags,
        time_created=__ret__.time_created,
        vcn_id=__ret__.vcn_id)


@_utilities.lift_output_func(get_data_safe_private_endpoint)
def get_data_safe_private_endpoint_output(data_safe_private_endpoint_id: Optional[pulumi.Input[str]] = None,
                                          opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDataSafePrivateEndpointResult]:
    """
    This data source provides details about a specific Data Safe Private Endpoint resource in Oracle Cloud Infrastructure Data Safe service.

    Gets the details of the specified Data Safe private endpoint.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_data_safe_private_endpoint = oci.DataSafe.get_data_safe_private_endpoint(data_safe_private_endpoint_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str data_safe_private_endpoint_id: The OCID of the private endpoint.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetDataKeysResult',
    'AwaitableGetDataKeysResult',
    'get_data_keys',
    'get_data_keys_output',
]

@pulumi.output_type
class GetDataKeysResult:
    """
    A collection of values returned by getDataKeys.
    """
    def __init__(__self__, apm_domain_id=None, data_key_type=None, data_keys=None, filters=None, id=None):
        if apm_domain_id and not isinstance(apm_domain_id, str):
            raise TypeError("Expected argument 'apm_domain_id' to be a str")
        pulumi.set(__self__, "apm_domain_id", apm_domain_id)
        if data_key_type and not isinstance(data_key_type, str):
            raise TypeError("Expected argument 'data_key_type' to be a str")
        pulumi.set(__self__, "data_key_type", data_key_type)
        if data_keys and not isinstance(data_keys, list):
            raise TypeError("Expected argument 'data_keys' to be a list")
        pulumi.set(__self__, "data_keys", data_keys)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="apmDomainId")
    def apm_domain_id(self) -> str:
        return pulumi.get(self, "apm_domain_id")

    @property
    @pulumi.getter(name="dataKeyType")
    def data_key_type(self) -> Optional[str]:
        return pulumi.get(self, "data_key_type")

    @property
    @pulumi.getter(name="dataKeys")
    def data_keys(self) -> Sequence['outputs.GetDataKeysDataKeyResult']:
        """
        The list of data_keys.
        """
        return pulumi.get(self, "data_keys")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetDataKeysFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetDataKeysResult(GetDataKeysResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDataKeysResult(
            apm_domain_id=self.apm_domain_id,
            data_key_type=self.data_key_type,
            data_keys=self.data_keys,
            filters=self.filters,
            id=self.id)


def get_data_keys(apm_domain_id: Optional[str] = None,
                  data_key_type: Optional[str] = None,
                  filters: Optional[Sequence[pulumi.InputType['GetDataKeysFilterArgs']]] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDataKeysResult:
    """
    This data source provides the list of Data Keys in Oracle Cloud Infrastructure Apm service.

    Lists all Data Keys for the specified APM domain. The caller may filter the list by specifying the 'dataKeyType'
    query parameter.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_data_keys = oci.Apm.get_data_keys(apm_domain_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        data_key_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str apm_domain_id: The OCID of the APM domain
    :param str data_key_type: Data key type.
    """
    __args__ = dict()
    __args__['apmDomainId'] = apm_domain_id
    __args__['dataKeyType'] = data_key_type
    __args__['filters'] = filters
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Apm/getDataKeys:getDataKeys', __args__, opts=opts, typ=GetDataKeysResult).value

    return AwaitableGetDataKeysResult(
        apm_domain_id=__ret__.apm_domain_id,
        data_key_type=__ret__.data_key_type,
        data_keys=__ret__.data_keys,
        filters=__ret__.filters,
        id=__ret__.id)


@_utilities.lift_output_func(get_data_keys)
def get_data_keys_output(apm_domain_id: Optional[pulumi.Input[str]] = None,
                         data_key_type: Optional[pulumi.Input[Optional[str]]] = None,
                         filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetDataKeysFilterArgs']]]]] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDataKeysResult]:
    """
    This data source provides the list of Data Keys in Oracle Cloud Infrastructure Apm service.

    Lists all Data Keys for the specified APM domain. The caller may filter the list by specifying the 'dataKeyType'
    query parameter.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_data_keys = oci.Apm.get_data_keys(apm_domain_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        data_key_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str apm_domain_id: The OCID of the APM domain
    :param str data_key_type: Data key type.
    """
    ...
